==> puma_pay-3.0.3.tar.gz: lib/redux/pumaPayActions.dart <==
import 'dart:convert';

import 'package:http/http.dart';
import 'package:puma_core/redux/core/coreAction.dart';
import 'package:puma_network/redux/api/apiAction.dart';
import 'package:puma_network/redux/network/networkState.dart';
import 'package:puma_pay/constants.dart';
import 'package:puma_pay/entities/appStoreReceiptValidationResult/appStoreReceiptValidationResult.dart';
import 'package:puma_pay/entities/product/product.dart';
import 'package:puma_pay/entities/purchaseDetail/purchaseDetail.dart';
import 'package:puma_pay/helpers/appStore.dart';
import 'package:redux/redux.dart';

class InitPayAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  final List<String>? productIDs;
  final bool? appStoreSandbox;
  final String? appleAppStorePassword;
  final String? verifyEndpoint;

  InitPayAction(
      {this.productIDs,
      this.appStoreSandbox,
      this.appleAppStorePassword,
      this.verifyEndpoint})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class IsStoreAvailableAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  IsStoreAvailableAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class IsStoreAvailableSuccessAction extends CoreAction {
  final bool available;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  IsStoreAvailableSuccessAction({this.available = false})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetStoreAvailableAction extends CoreAction {
  bool storeAvailable;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetStoreAvailableAction({required this.storeAvailable})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetProductsAction extends CoreAction {
  final List<String>? productIDs;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetProductsAction({this.productIDs})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetProductsSuccessAction extends CoreAction {
  final List<Product>? products;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetProductsSuccessAction({this.products})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class PurchaseProductAction extends CoreAction {
  final String productID;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  PurchaseProductAction({this.productID = ""})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class RestorePurchaseAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  RestorePurchaseAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseAction extends CoreAction {
  Map<String, dynamic> receipt;
  final PurchaseDetail purchaseDetail;
  final String storeName;
  final String productID;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  VerifyInAppPurchaseAction(
      {required this.receipt,
      required this.productID,
      required this.storeName,
      required this.purchaseDetail})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseWithEndpointAction extends PostAction {
  final String path;
  final String productID;
  final String storeName;
  final PurchaseDetail purchaseDetail;
  final Map<dynamic, dynamic> body;

  VerifyInAppPurchaseWithEndpointAction(
      {required this.body,
      required this.path,
      required this.storeName,
      required this.productID,
      required this.purchaseDetail})
      : super("$path", body);

  decodeResponse(Store store, Response data) {
    Map<String, dynamic> _data = json.decode(data.body);

    store.dispatch(VerifyInAppPurchaseSuccessAction(
        productID: this.productID,
        purchaseDetail: this.purchaseDetail,
        valid: _data["valid"]));
  }
}

class VerifyInAppPurchaseWithoutEndpointAction extends CustomPostAction {
  final String path;
  final String productID;
  final String storeName;
  final PurchaseDetail purchaseDetail;
  final Map<dynamic, dynamic> body;

  VerifyInAppPurchaseWithoutEndpointAction(
      {required this.body,
      required this.path,
      required this.storeName,
      required this.productID,
      required this.purchaseDetail})
      : super("$path", body);

  decodeResponse(Store store, Response data) {
    var valid = false;
    if (checkReceiptValidity(
        AppStoreReceiptValidationResult.fromJson(data.body)!)) {
      valid = true;
    } else {
      valid = false;
    }

    store.dispatch(VerifyInAppPurchaseSuccessAction(
        valid: valid,
        productID: this.productID,
        purchaseDetail: this.purchaseDetail));
  }
}

class VerifyInAppPurchaseSuccessAction extends CoreAction {
  final String productID;
  final PurchaseDetail purchaseDetail;
  final int timestamp;
  final bool? valid;
  final String dispatcherKey = constDispatcherKey;
  VerifyInAppPurchaseSuccessAction(
      {required this.productID, required this.purchaseDetail, this.valid})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseErrorAction extends CoreAction {
  final String productID;
  final PurchaseDetail purchaseDetail;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  VerifyInAppPurchaseErrorAction(
      {required this.productID, required this.purchaseDetail})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetPurchasePendingAction extends CoreAction {
  bool purchasePending;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetPurchasePendingAction({required this.purchasePending})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetRestoringPurchaseAction extends CoreAction {
  bool restoringPurchase;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetRestoringPurchaseAction({required this.restoringPurchase})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class CustomPostAction extends RequestAction {
  final Object body;
  Future<Response> apiCall(NetworkState store) async {
    print("CustomPostAction Endpoint: ${Uri.parse(path)}");
    return await post(
      Uri.parse(path),
      body: jsonEncode(body),
      headers: headers(store),
      encoding: Encoding.getByName("application/json"),
    );
  }

  CustomPostAction(String path, this.body) : super(path, "POST");
}

==> puma_pay-3.0.5.tar.gz: lib/redux/pumaPayActions.dart <==
import 'dart:convert';

import 'package:http/http.dart';
import 'package:puma_core/redux/core/coreAction.dart';
import 'package:puma_network/redux/api/apiAction.dart';
import 'package:puma_network/redux/network/networkState.dart';
import 'package:puma_pay/constants.dart';
import 'package:puma_pay/entities/appStoreReceiptValidationResult/appStoreReceiptValidationResult.dart';
import 'package:puma_pay/entities/product/product.dart';
import 'package:puma_pay/entities/purchaseDetail/purchaseDetail.dart';
import 'package:puma_pay/helpers/appStore.dart';
import 'package:redux/redux.dart';

class InitPayAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  final List<String>? productIDs;
  final String? appleAppStorePassword;
  final String? verifyEndpoint;

  InitPayAction({
    this.productIDs,
    this.appleAppStorePassword,
    this.verifyEndpoint,
  }) : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class IsStoreAvailableAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  IsStoreAvailableAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class IsStoreAvailableSuccessAction extends CoreAction {
  final bool available;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  IsStoreAvailableSuccessAction({this.available = false})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetStoreAvailableAction extends CoreAction {
  bool storeAvailable;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetStoreAvailableAction({required this.storeAvailable})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetProductsAction extends CoreAction {
  final List<String>? productIDs;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetProductsAction({this.productIDs})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class GetProductsSuccessAction extends CoreAction {
  final List<Product>? products;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  GetProductsSuccessAction({this.products})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class PurchaseProductAction extends CoreAction {
  final String productID;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  PurchaseProductAction({this.productID = ""})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class RestorePurchaseAction extends CoreAction {
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  RestorePurchaseAction()
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseAction extends CoreAction {
  Map<String, dynamic> receipt;
  final PurchaseDetail purchaseDetail;
  final String storeName;
  final String productID;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  VerifyInAppPurchaseAction(
      {required this.receipt,
      required this.productID,
      required this.storeName,
      required this.purchaseDetail})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseWithEndpointAction extends PostAction {
  final String path;
  final String productID;
  final String storeName;
  final PurchaseDetail purchaseDetail;
  final Map<dynamic, dynamic> body;

  VerifyInAppPurchaseWithEndpointAction(
      {required this.body,
      required this.path,
      required this.storeName,
      required this.productID,
      required this.purchaseDetail})
      : super("$path", body);

  decodeResponse(Store store, Response data) {
    Map<String, dynamic> _data = json.decode(data.body);

    store.dispatch(VerifyInAppPurchaseSuccessAction(
        productID: this.productID,
        purchaseDetail: this.purchaseDetail,
        valid: _data["valid"]));
  }
}

class VerifyInAppPurchaseWithoutEndpointAction extends CustomPostAction {
  final String path;
  final String productID;
  final String storeName;
  final PurchaseDetail purchaseDetail;
  final Map<dynamic, dynamic> body;

  VerifyInAppPurchaseWithoutEndpointAction({
    required this.body,
    required this.path,
    required this.storeName,
    required this.productID,
    required this.purchaseDetail,
  }) : super("$path", body);

  decodeResponse(Store store, Response data) {
    print("📡 Response: ${data.statusCode} from $path");
    var valid = false;
    var receipt = AppStoreReceiptValidationResult.fromJson(data.body)!;

    if (receipt.status == 21007) {
      var verifyEndpoint = "$appStoreEndpointSandbox$appStoreVerifyRoute";
      print("🎟 Receipt status: 21007 -> Check $verifyEndpoint");

      store.dispatch(
        VerifyInAppPurchaseWithoutEndpointAction(
          body: this.body,
          purchaseDetail: this.purchaseDetail,
          storeName: this.storeName,
          productID: this.productID,
          path: verifyEndpoint,
        ),
      );
    } else {
      if (checkReceiptValidity(receipt)) {
        valid = true;
      } else {
        valid = false;
      }

      store.dispatch(
        VerifyInAppPurchaseSuccessAction(
          valid: valid,
          productID: this.productID,
          purchaseDetail: this.purchaseDetail,
        ),
      );
    }
  }
}

class VerifyInAppPurchaseSuccessAction extends CoreAction {
  final String productID;
  final PurchaseDetail purchaseDetail;
  final int timestamp;
  final bool? valid;
  final String dispatcherKey = constDispatcherKey;
  VerifyInAppPurchaseSuccessAction(
      {required this.productID, required this.purchaseDetail, this.valid})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class VerifyInAppPurchaseErrorAction extends CoreAction {
  final String productID;
  final PurchaseDetail purchaseDetail;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;
  VerifyInAppPurchaseErrorAction(
      {required this.productID, required this.purchaseDetail})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetPurchasePendingAction extends CoreAction {
  bool purchasePending;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetPurchasePendingAction({required this.purchasePending})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class SetRestoringPurchaseAction extends CoreAction {
  bool restoringPurchase;
  final int timestamp;
  final String dispatcherKey = constDispatcherKey;

  SetRestoringPurchaseAction({required this.restoringPurchase})
      : this.timestamp = DateTime.now().millisecondsSinceEpoch;
}

class CustomPostAction extends RequestAction {
  final Object body;
  Future<Response> apiCall(NetworkState store) async {
    print("CustomPostAction Endpoint: ${Uri.parse(path)}");
    return await post(
      Uri.parse(path),
      body: jsonEncode(body),
      headers: headers(store),
      encoding: Encoding.getByName("application/json"),
    );
  }

  CustomPostAction(String path, this.body) : super(path, "POST");
}
